@@ -134,6 +134,7 @@ def deploy_teams(
     "-f",
     type=str,
     help="The target Orbit Workbench manifest file (yaml).",
+    required=True,
 )
 @click.option(
     "--username",
@@ -148,8 +149,8 @@ def deploy_teams(
     help="Dockerhub password (Required only for the first deploy).",
 )
 @click.option(
-    "--skip-images/--no-skip-images",
-    default=False,
+    "--skip-images/--build-images",
+    default=True,
     help="Skip Docker images updates (Usually for development purpose).",
     show_default=True,
 )
@@ -624,17 +625,6 @@ def run_container() -> None:
     except ImportError:
         raise click.ClickException('The "utils" submodule is required to use "run" commands')
     pass
-    try:
-        from kubespawner.objects import make_pod  # noqa: F401
-    except ImportError:
-        raise click.ClickException(
-            (
-                'The "jupyterhub-kubespawner" package is required to use "run" commands.'
-                'Please install it with "pip install --no-deps jupyterhub-kubespawner~=0.15.0" command,'
-                'or install our "kubespawner" submodule'
-            )
-        )
-    pass
 
 
 @run_container.command(name="python", help="Run python script in a container")
