@@ -51,6 +51,34 @@ def _orbit_system_commons(context: "Context", output_path: str) -> None:
         file.write(content)
 
 
+def _kubeflow_namespaces(context: "Context", clean_up: bool = True) -> str:
+    output_path = os.path.join(".orbit.out", context.name, "kubectl", "orbit-system")
+    os.makedirs(output_path, exist_ok=True)
+    if clean_up:
+        _cleanup_output(output_path=output_path)
+
+    filenames = ["kubeflow_namespace.yaml"]
+
+    for filename in filenames:
+        input = os.path.join(MODELS_PATH, "kubeflow", filename)
+        output = os.path.join(output_path, filename)
+
+        with open(input, "r") as file:
+            content: str = file.read()
+        content = resolve_parameters(
+            content,
+            dict(
+                env_name=context.name,
+                account_id=context.account_id,
+                region=context.region,
+            ),
+        )
+        with open(output, "w") as file:
+            file.write(content)
+
+    return output_path
+
+
 def _orbit_controller(context: "Context", output_path: str) -> None:
     filenames = ["01a-orbit-controller.yaml", "01b-cert-manager.yaml"]
 
@@ -69,12 +97,33 @@ def _orbit_controller(context: "Context", output_path: str) -> None:
                 k8s_utilities_image=f"{context.images.k8s_utilities.repository}:"
                 f"{context.images.k8s_utilities.version}",
                 image_pull_policy="Always" if aws_orbit.__version__.endswith(".dev0") else "IfNotPresent",
-                certArn=context.networking.frontend.ssl_cert_arn,
-                cognitoAppClientId=context.user_pool_client_id,
-                cognitoUserPoolID=context.user_pool_id,
                 account_id=context.account_id,
                 region=context.region,
-                cognitoUserPoolDomain=context.cognito_external_provider_domain,
+                sts_ep="legacy" if context.networking.data.internet_accessible else "regional",
+            ),
+        )
+        with open(output, "w") as file:
+            file.write(content)
+
+
+def _orbit_image_replicator(context: "Context", output_path: str) -> None:
+    filenames = ["01c-image-replicator.yaml"]
+
+    for filename in filenames:
+        input = os.path.join(MODELS_PATH, "orbit-system", filename)
+        output = os.path.join(output_path, filename)
+
+        with open(input, "r") as file:
+            content: str = file.read()
+        content = resolve_parameters(
+            content,
+            dict(
+                env_name=context.name,
+                orbit_controller_image=f"{context.images.orbit_controller.repository}:"
+                f"{context.images.orbit_controller.version}",
+                k8s_utilities_image=f"{context.images.k8s_utilities.repository}:"
+                f"{context.images.k8s_utilities.version}",
+                image_pull_policy="Always" if aws_orbit.__version__.endswith(".dev0") else "IfNotPresent",
             ),
         )
         with open(output, "w") as file:
@@ -230,7 +279,6 @@ def _generate_orbit_system_manifest(context: "Context", clean_up: bool = True) -
         _cleanup_output(output_path=output_path)
     _orbit_system_commons(context=context, output_path=output_path)
     _orbit_controller(context=context, output_path=output_path)
-
     if context.account_id is None:
         raise ValueError("context.account_id is None!")
     if context.user_pool_id is None:
@@ -240,8 +288,17 @@ def _generate_orbit_system_manifest(context: "Context", clean_up: bool = True) -
     if context.identity_pool_id is None:
         raise ValueError("context.identity_pool_id is None!")
 
+    if context.install_image_replicator or not context.networking.data.internet_accessible:
+        _logger.debug("Deploying Pod Image Modifier and Image Replicator")
+        _orbit_image_replicator(output_path=output_path, context=context)
+    else:
+        _logger.debug("Skipping deployment of Pod Image Modifier and Image Replicator")
+
     if context.install_ssm_agent:
+        _logger.debug("Deploying SSM Agent Installer")
         _ssm_agent_installer(output_path=output_path, context=context)
+    else:
+        _logger.debug("Skipping deployment of SSM Agent Installer")
 
     _sm_operator_installer(output_path=output_path, context=context)
 
@@ -259,10 +316,31 @@ def _generate_env_manifest(context: "Context", clean_up: bool = True) -> Tuple[s
     output = os.path.join(output_path, filename)
     shutil.copyfile(src=input, dst=output)
 
+    with open(input, "r") as file:
+        content = file.read()
+
+    content = utils.resolve_parameters(
+        content,
+        dict(
+            env_name=context.name,
+            orbit_controller_image=f"{context.images.orbit_controller.repository}:"
+            f"{context.images.orbit_controller.version}",
+            k8s_utilities_image=f"{context.images.k8s_utilities.repository}:" f"{context.images.k8s_utilities.version}",
+            image_pull_policy="Always" if aws_orbit.__version__.endswith(".dev0") else "IfNotPresent",
+            certArn=context.networking.frontend.ssl_cert_arn,
+            cognitoAppClientId=context.user_pool_client_id,
+            cognitoUserPoolID=context.user_pool_id,
+            account_id=context.account_id,
+            region=context.region,
+            cognitoUserPoolDomain=context.cognito_external_provider_domain,
+        ),
+    )
+    with open(output, "w") as file:
+        file.write(content)
+
     # kubeflow jupyter launcher configmap
     input = os.path.join(MODELS_PATH, "kubeflow", "kf-jupyter-launcher.yaml")
     output = os.path.join(output_path, "kf-jupyter-launcher.yaml")
-
     with open(input, "r") as file:
         content = file.read()
 
@@ -418,12 +496,16 @@ def deploy_env(context: "Context") -> None:
         sh.run(f"kubectl delete jobs -l app=cert-manager -n orbit-system --context {k8s_context} --wait")
         sh.run(f"kubectl apply -f {output_path} --context {k8s_context} --wait")
 
-        kubeflow.deploy_kubeflow(context=context)
-
         # orbit-system
         output_path = _generate_orbit_system_manifest(context=context)
         sh.run(f"kubectl apply -f {output_path} --context {k8s_context} --wait")
 
+        # kubeflow-namespaces
+        output_path = _kubeflow_namespaces(context=context)
+        sh.run(f"kubectl apply -f {output_path} --context {k8s_context} --wait")
+
+        kubeflow.deploy_kubeflow(context=context)
+
         # env
         (output_path, patch) = _generate_env_manifest(context=context)
         sh.run(f"kubectl apply -f {output_path} --context {k8s_context} --wait")
@@ -433,11 +515,35 @@ def deploy_env(context: "Context") -> None:
         sh.run("kubectl rollout restart deployment jupyter-web-app-deployment -n kubeflow")
         # Enable ENIs
         sh.run(f"kubectl set env daemonset aws-node -n kube-system --context {k8s_context} ENABLE_POD_ENI=true")
+        sh.run(
+            f"kubectl set env daemonset aws-node -n kube-system --context {k8s_context} DISABLE_TCP_EARLY_DEMUX=true"
+        )
 
         # Restart orbit-system deployments and statefulsets to force reload of caches etc
         sh.run(f"kubectl rollout restart deployments -n orbit-system --context {k8s_context}")
         sh.run(f"kubectl rollout restart statefulsets -n orbit-system --context {k8s_context}")
 
+        # Confirm orbit-system Service Endpoints
+        def confirm_endpoints(name: str, namespace: str) -> None:
+            subsets = k8s.get_service_endpoints(name=name, namespace=namespace, k8s_context=k8s_context)
+            if subsets:
+                for subset in subsets:
+                    for address in subset.get("addresses", []):
+                        _logger.debug(
+                            "Service: %s Namespace: %s Hostname: %s IP: %s",
+                            name,
+                            namespace,
+                            address.get("hostname"),
+                            address.get("ip"),
+                        )
+            else:
+                raise Exception("No Endpoints found for Service: %s Namespace: %s", name, namespace)
+
+        confirm_endpoints(name="podsettings-pod-modifier", namespace="orbit-system")
+        confirm_endpoints(name="landing-page-service", namespace="orbit-system")
+        if context.install_image_replicator or not context.networking.data.internet_accessible:
+            confirm_endpoints(name="pod-image-updater", namespace="orbit-system")
+
 
 def deploy_team(context: "Context", team_context: "TeamContext") -> None:
     eks_stack_name: str = f"eksctl-orbit-{context.name}-cluster"
